@@ -28,3 +28,6 @@ def call_with_inject(func, data):
     return func(**params)
 
 
+class classproperty(property):
+    def __get__(self, cls, owner):
+        return self.fget.__get__(None, owner)()
