@@ -15,6 +15,12 @@ HEXLIFY_CHARS = "0123456789abcdefABCDEF"
 URLSAFEB64_CHARS = "-0123456789=ABCDEFGHIJKLMNOPQRSTUVWXYZ_abcdefghijklmnopqrstuvwxyz\r\n"
 BASE64_CHARS = "+/0123456789=ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz\r\n"
 
+SHI = 10
+BAI = SHI * 10
+QIAN = BAI * 10
+WAN = QIAN * 10
+YI = WAN * WAN
+
 default_encodings = ["utf8", "gb18030"]
 
 
@@ -352,3 +358,71 @@ def combinations(values, length):
         for subword in substrings(word, length):
             result_words.add(subword)
     return result_words
+
+
+def captital_number(value, yuan="圆", digits="零壹贰叁肆伍陆柒捌玖", places="拾佰仟万亿", negative="负", float_places="角分厘毫丝忽微"):
+    from .numericutils import float_split
+
+    sign, int_part, float_part = float_split(value, precision=7)
+
+    def parse4(value):
+        qian = value // QIAN
+        value = value % QIAN
+        bai = value // BAI
+        value = value % BAI
+        shi = value // SHI
+        value = value % SHI
+        ge = value
+        return digits[qian] + places[2] + digits[bai] + places[1] + digits[shi] + places[0] + digits[ge]
+
+    def parse8(value):
+        high = value // WAN
+        low = value % WAN
+        return parse4(high) + places[3] + parse4(low)
+
+    def parse(value):
+        yis = []
+        while value:
+            yis.append(value % YI)
+            value //= YI
+        yis.reverse()
+        return places[4].join([parse8(x) for x in yis])
+
+    def remove0(value_string):
+        z0 = digits[0]
+        z00 = digits[0] +  digits[0]
+        for place in places:
+            value_string = value_string.replace(digits[0] + place, digits[0])
+        while z00 in value_string:
+            value_string = value_string.replace(z00, z0)
+        if value_string.startswith(z0):
+            value_string = value_string[1:]
+        if value_string.endswith(z0):
+            value_string = value_string[:-1]
+        return value_string
+
+    def parse_float_part(value):
+        if not value:
+            return ""
+        result = ""
+        for index, c in enumerate("{:07d}".format(value)):
+            if index > len(float_places):
+                break
+            cv = int(c)
+            if cv:
+                result += digits[cv] + float_places[index]
+        return result
+
+    int_string = parse(int_part)
+    int_string = remove0(int_string)
+    if not int_string:
+        int_string = digits[0]
+
+    float_string = parse_float_part(float_part)
+
+    result = int_string + yuan + float_string
+    if sign < 0:
+        result = negative + result
+
+    return result
+
